@@ -9,12 +9,10 @@ module Debci
 
     attr_reader :root_directory
 
-    def initialize(root_directory)
+    def initialize(root_directory=Debci.config.html_dir)
       @root_directory = root_directory
       @repository = Debci::Repository.new
-      @package_prefixes = (('0'..'9').to_a + ('a'..'z').to_a + ('liba'..'libz').to_a).select do |p|
-        @repository.search('^' + p).size > 0
-      end.sort
+      @package_prefixes = @repository.prefixes
 
       @head = read_config_file('head.html')
       @footer = read_config_file('footer.html')
@@ -25,19 +23,38 @@ module Debci
     end
 
     def status(filename)
+      @status_nav = load_template(:status_nav)
       expand_template(:status, filename)
     end
 
+    def status_alerts(filename)
+      @tmpfail = @repository.tmpfail_packages
+      @alert_number = @tmpfail.length
+      expand_template(:status_alerts, filename)
+    end
+
+    def blacklist(filename)
+      @status_nav = load_template(:status_nav)
+      expand_template(:blacklist, filename)
+    end
+
     def package(package, filename)
       @package = package
+      @moretitle = package.name
       expand_template(:package, filename)
     end
 
     def prefix(prefix, filename)
       @prefix = prefix
+      @moretitle = prefix
       expand_template(:packagelist, filename)
     end
 
+    # expand { SUITE } macro in URLs
+    def expand_url(url, suite)
+      url && url.gsub('{SUITE}', suite)
+    end
+
     def history(package, suite, architecture, filename)
       @package = package
       @suite = suite
@@ -45,14 +62,16 @@ module Debci
       @packages_dir = 'data/packages'
       @package_dir = File.join(suite, architecture, package.prefix, package.name)
       @autopkgtest_dir = 'data/autopkgtest'
-      @site_url = 'http://ci.debian.net'
+      @site_url = expand_url(Debci.config.url_base, @suite)
+      @artifacts_url_base = expand_url(Debci.config.artifacts_url_base, @suite)
+      @moretitle = "#{package.name}/#{suite}/#{architecture}"
       expand_template(:history, filename)
     end
 
     private
 
-    def with_layout
-      read_template(:layout).result(binding)
+    def load_template(template)
+      read_template(template).result(binding)
     end
 
     def read_template(name)
@@ -68,7 +87,7 @@ module Debci
 
       @root = directory.split('/').map { |_| '..' }.join('/')
 
-      html = with_layout do
+      html = load_template(:layout) do
         read_template(template).result(binding)
       end
 
