@@ -30,7 +30,7 @@ list_packages_from_archive() {
 
 get_maintainers() {
   local pkg="$1"
-  grep_sources -n -s Maintainer,Uploaders -F Package -X "$pkg"  | sed -e 's/,\s*/\n/g' | sed -e 's/.*<\(.*\)>.*/\1/'
+  grep_sources -n -s Maintainer,Uploaders -F Package -X "$pkg"  | sed -e 's/,\s*/\n/g' | sed -e 's/.*<\(.*\)>.*/\1/; /^$/d'
 }
 
 
@@ -62,6 +62,11 @@ autopkgtest_dir_for_package() {
   echo "${debci_autopkgtest_dir}/${pkg_dir}"
 }
 
+autopkgtest_incoming_dir_for_package() {
+  local pkg="$1"
+  pkg_dir=$(echo "$pkg" | sed -e 's/\(\(lib\)\?.\).*/\1\/&/')
+  echo "${debci_autopkgtest_incoming_dir}/${pkg_dir}"
+}
 
 status_dir_for_package() {
   local pkg="$1"
@@ -102,10 +107,20 @@ report_status() {
         color=5 # should never get here though
         ;;
     esac
-    /bin/echo -e "${pkg} \033[38;5;${color}m${status}\033[m" "$duration"
+    log "${pkg} \033[38;5;${color}m${status}\033[m" "$duration"
   else
     log "$pkg" "$status" "$duration"
-  fi
+  fi >&2
+}
+
+seconds_to_human_time() {
+  local seconds="$1"
+  local hours=$(( $seconds / 3600 ))
+  local minutes=$(( ($seconds % 3600) / 60 ))
+  local seconds=$(( $seconds - ($hours * 3600) - ($minutes * 60) ))
+  local human_time="${hours}h ${minutes}m ${seconds}s"
+
+  echo "$human_time"
 }
 
 
@@ -113,11 +128,35 @@ command_available() {
   which "$1" >/dev/null 2>/dev/null
 }
 
+# Makes sure $lockfile exists, and is owned by the debci user
+ensure_lockfile() {
+  local lockfile="$1"
+  if [ ! -f "$lockfile" ]; then
+    touch "$lockfile"
+    chown $debci_user:$debci_group "$lockfile"
+  fi
+}
+
 run_with_lock_or_exit() {
-  lockfile="$1"
+  local lockfile="$1"
+  ensure_lockfile "$lockfile"
   shift
   (
-    flock -n 9 || exit 0
+    flock --nonblock 9 || exit 0
     "$@"
   ) 9> "$lockfile"
 }
+
+run_with_shared_lock() {
+  local lockfile="$1"
+  shift
+  ensure_lockfile "$lockfile"
+  flock --shared "$lockfile" "$@"
+}
+
+run_with_exclusive_lock() {
+  local lockfile="$1"
+  shift
+  ensure_lockfile "$lockfile"
+  flock --exclusive "$lockfile" "$@"
+}
