@@ -37,6 +37,9 @@ describe Debci::Repository do
     mkdir_p 'packages/testing/amd64/r/ruby-ffi'
     mkdir_p 'packages/testing/i386/r/ruby-ffi'
 
+    latest_status 'packages/unstable/amd64/r/ruby-ffi', {'status' => 'tmpfail',
+                                                         'previous_status' => 'pass' }
+
     mkdir_p 'packages/unstable/amd64/r/rubygems-integration'
     mkdir_p 'packages/unstable/i386/r/rubygems-integration'
     mkdir_p 'packages/testing/amd64/r/rubygems-integration'
@@ -83,6 +86,10 @@ describe Debci::Repository do
     expect(repository.suites).to eq(['testing', 'unstable'])
   end
 
+  it 'knows about prefixes' do
+    expect(repository.prefixes).to include('d', 'r')
+  end
+
   it 'knows about packages' do
     expect(repository.packages.sort).to include('debci', 'rake')
   end
@@ -141,9 +148,9 @@ describe Debci::Repository do
     glob = File.join(@datadir, 'packages/{unstable}/{amd64}/r/rake/[0-9]*.json')
     statuses_reversed = Dir.glob(glob).sort_by { |f| File.basename(f) }.reverse
 
-    repository.stub(:architectures).and_return(['amd64'])
-    repository.stub(:suites).and_return(['unstable'])
-    Dir.stub(:glob).with(glob).and_return(statuses_reversed)
+    expect(repository).to receive(:architectures).and_return(['amd64'])
+    expect(repository).to receive(:suites).and_return(['unstable'])
+    expect(Dir).to receive(:glob).with(glob).and_return(statuses_reversed)
 
     news = repository.news_for('rake')
 
@@ -178,4 +185,20 @@ describe Debci::Repository do
       expect([:pass, :fail, :tmpfail]).to include(item.status)
     end
   end
+
+  it 'knows which packages are temporarily failing' do
+    tmpfail_packages = repository.tmpfail_packages
+
+    expect(tmpfail_packages).to be_a(Array)
+    expect(tmpfail_packages.length).to eq(1)
+
+    tmpfail_packages.each do |package|
+      expect(package).to be_a(Debci::Package)
+      expect(package.name).to eq('ruby-ffi')
+
+      package.status.flatten.each do |p|
+        expect([:tmpfail, :no_test_data]).to include(p.status)
+      end
+    end
+  end
 end
