@@ -14,17 +14,18 @@ report() {
 
 testdir=$(dirname $0)
 
+start_time=$(date +%s)
 tests=0
 passed=0
 failed=0
 cd "$testdir"
-for test_script in $(find . -name 'test_*' -type f -executable); do
+for test_script in $(find . -name 'test_*.sh' -and -not -name 'test_helper.sh'); do
   tests=$(($tests + 1))
   tmpdir=$(mktemp -d)
   echo "$test_script"
   (
     set +e
-    $test_script
+    sh $test_script
     echo "$?" > $tmpdir/.exit_status
   ) | sed -e 's/^/    /'
   rc=$(cat $tmpdir/.exit_status)
@@ -37,5 +38,7 @@ for test_script in $(find . -name 'test_*' -type f -executable); do
   fi
   rm -rf "$tmpdir"
 done
+end_time=$(date +%s)
+echo "Finished in $(($end_time - $start_time)) seconds"
 
 exit $failed
