@@ -20,4 +20,19 @@ test_with_blacklist() {
   assertTrue 'pkg3 should be listed' "grep -q pkg3 $debci_config_dir/pkgs"
 }
 
+test_executable_whitelist() {
+  echo '#!/bin/sh' > $debci_config_dir/whitelist
+  echo 'printf "pkg1\n"' >> $debci_config_dir/whitelist
+  echo 'printf "pkg2\n"' >> $debci_config_dir/whitelist
+  chmod +x $debci_config_dir/whitelist
+
+  assertEquals "pkg1 pkg2" "$(debci list-packages | xargs echo)"
+}
+
+test_remove_duplicates() {
+  echo pkg1 > $debci_config_dir/whitelist
+  echo pkg1 >> $debci_config_dir/whitelist
+  assertEquals "pkg1" "$(debci list-packages)"
+}
+
 . shunit2
