@@ -28,6 +28,22 @@ mimetype.assign += (".log" => "text/plain; charset=utf-8")
 dir-listing.encoding        = "utf-8"
 server.dir-listing          = "enable"
 index-file.names            = ("index.html", "index.htm")
+server.modules             += ("mod_setenv")
+\$HTTP["url"] =~ "\.log\.gz" {
+  server.error-handler-404 = "/notfound.log.gz"
+  setenv.add-response-header = (
+    "Content-Encoding" => "gzip",
+    "Content-Type" => "text/plain; charset=utf-8"
+  )
+}
+server.modules             += ("mod_rewrite")
+url.rewrite-if-not-file = (
+  "^(.*\.log)\$" => "\$1.moved"
+)
+server.modules             += ("mod_redirect")
+url.redirect = (
+  "^(.*\.log)\.moved\$" => "\$1.gz"
+)
 EOF
 
 echo "I: Go to: http://localhost:$port/"
